So You Want to Contribute...
============================

Communication
~~~~~~~~~~~~~

Matrix
   #octavia:matrix.otc-service.com

Reporting a Bug
~~~~~~~~~~~~~~~

github

Getting Your Patch Merged
~~~~~~~~~~~~~~~~~~~~~~~~~

...
In addition, some changes may require a release note.  Any patch that
changes functionality, adds functionality, or addresses a significant
bug should have a release note. Release notes can be created using the "reno"
tool by running "reno new <summary-message>".

Keep in mind that the best way to make sure your patches are reviewed in
a timely manner is to review other people's patches.  We're engaged in a
cooperative enterprise here.
